@@ -460,10 +460,11 @@ class ConvolvedSceneCube(object):
         self.warnings = {}
         self.scene = scene
         self.psf_library = psf_library
-        self.aper_width = instrument.get_aperture_pars()['disp']
-        self.aper_height = instrument.get_aperture_pars()['xdisp']
-        self.multishutter = instrument.get_aperture_pars()['multishutter']
-        nslice_str = instrument.get_aperture_pars()['nslice']
+        self.aper_width = instrument.get_slit_pars()['disp']
+        self.aper_height = instrument.get_slit_pars()['xdisp']
+        self.multishutter = instrument.get_slit_pars()['multishutter']
+        nslice_str = instrument.get_slit_pars()['nslice']
+        self.slit_shape = instrument.get_slit_pars()['slit_shape']
 
         if nslice_str is not None:
             self.nslice = int(nslice_str)
@@ -477,7 +478,7 @@ class ConvolvedSceneCube(object):
         self.fov_size = self.get_fov_size()
 
         # Figure out what the relevant wavelength range is, given the instrument mode
-        wrange = self.current_instrument.get_wave_range()
+        wrange = self.instrument.get_wave_range()
 
         self.source_spectra = []
         spectra = []
@@ -543,8 +544,8 @@ class ConvolvedSceneCube(object):
             spectrum.trim(wrange['wmin'], wrange['wmax'])
             spectrum = instrument.spectrometer_convolve(spectrum)
             self.source_spectra.append(spectrum)
-            # include the background in the wavelength array calculation, so it's eventually properly sampled
-            background.trim(wrange['wmin'], wrange['wmax'])
+        # include the background in the wavelength array calculation, so it's eventually properly sampled
+        background.trim(wrange['wmin'], wrange['wmax'])
 
         """
         different spectra will have different sets of wavelengths. the obvious future
@@ -555,9 +556,10 @@ class ConvolvedSceneCube(object):
         """
         self.wave = self.source_spectra[0].wave
         for s in self.source_spectra:
-            self.wave = syn.utils.merge_wavelengths(self.wave, s.wave)
+            # Specifying the threshold fixes bug JETC-1758
+            self.wave = syn.utils.merge_wavelengths(self.wave, s.wave, threshold=PANDEIA_ATOL)
         # Also merge in the background wavelengths
-        self.wave = syn.utils.merge_wavelengths(self.wave, background.wave)
+        self.wave = syn.utils.merge_wavelengths(self.wave, background.wave, threshold=PANDEIA_ATOL)
 
         projection_type = instrument.projection_type
 
@@ -607,7 +609,7 @@ class ConvolvedSceneCube(object):
 
         instrument_name = self.instrument.get_name()
         aperture_name = self.instrument.get_aperture()
-        readout_pattern = self.instrument.detector["readout_pattern"]
+        readout_pattern = self.instrument.detector.get("readout_pattern", "default")
         psf_shape = self.psf_library.get_shape(instrument_name, aperture_name)
         psf_pix_scl_x, psf_pix_scl_y = self.psf_library.get_pix_scale(instrument_name, aperture_name)
         psf_size = np.max([psf_shape[0] * psf_pix_scl_x, psf_shape[1] * psf_pix_scl_y])
@@ -706,14 +708,14 @@ class ConvolvedSceneCube(object):
         # see coord.py Grid definition for more explanation
         flux_cube_list = [
             np.zeros(
-                (detector_shape[1],
-                 detector_shape[0],
+                (int(detector_shape[1]),
+                 int(detector_shape[0]),
                  self.nw), dtype=np.float32) for ir in range(self.nslice)]
 
         flux_plus_bg_list = [
             np.zeros(
-                (detector_shape[1],
-                 detector_shape[0],
+                (int(detector_shape[1]),
+                 int(detector_shape[0]),
                  self.nw), dtype=np.float32) for ir in range(self.nslice)]
 
         if background is not None:
@@ -755,14 +757,14 @@ class ConvolvedSceneCube(object):
                     psf = AdvancedPSF(
                         self.wave[iw],
                         self.psf_library,
-                        instrument_name,
-                        aperture_name,
+                        self.instrument,
                         psf_source_offset=unique_offset,
                         model_scene=current_scene,
                         aper_width=self.aper_width,
                         aper_height=self.aper_height,
                         multishutter=self.multishutter,
                         nslice=self.nslice,
+                        slit_shape=self.slit_shape,
                         bg_w=self.bg[iw],
                         single=self.single_point_source,
                         empty_scene = self.empty_scene
@@ -775,14 +777,14 @@ class ConvolvedSceneCube(object):
                         AdvancedPSF(
                             self.wave[iw],
                             self.psf_library,
-                            instrument_name,
-                            aperture_name,
+                            self.instrument,
                             psf_source_offset=unique_offset,
                             model_scene=current_scene,
                             aper_width=self.aper_width,
                             aper_height=self.aper_height,
                             multishutter=self.multishutter,
                             nslice=self.nslice,
+                            slit_shape=self.slit_shape,
                             bg_w=0.
                         )
                     )
@@ -877,10 +879,8 @@ class AdvancedPSF(object):
         Wavelength (in microns) at which the PSF is to be calculated
     psf_library: psf_library.PSFLibrary instance
         Library of PSFs to use for convolution kernels
-    instrument: string
-        Name of instrument being used
-    mode: string
-        Name of observing mode being used
+    instrument: Instrument instance
+        The Instrument instance being used.
     model_scene: astro_spectrum.ModelSceneCube instance
         Model scene as sampled into an image cube
     aper_width: float
@@ -899,13 +899,16 @@ class AdvancedPSF(object):
         only convolve a field the size of the PSF kernel (leaving the rest of the FOV at zero source flux).
     """
 
-    def __init__(self, wave, psf_library, instrument, mode, model_scene=None, psf_source_offset=(0, 0),
-                 aper_width=None, aper_height=None, multishutter=[(0.0, 0.0)], nslice=None, bg_w=0, single=False, empty_scene=False):
+    def __init__(self, wave, psf_library, instrument, model_scene=None, psf_source_offset=(0, 0),
+                 aper_width=None, aper_height=None, multishutter=[(0.0, 0.0)], nslice=None, slit_shape=None, 
+                 bg_w=0, single=False, empty_scene=False):
 
         self.warnings = {}
+        instrument_name = instrument.get_name()
+        aperture_name = instrument.get_aperture()
 
         # The advanced PSF gets its intensity map from a PSF library
-        profile = psf_library.get_psf(wave, instrument, mode, source_offset=psf_source_offset)
+        profile = psf_library.get_psf(wave, instrument_name, aperture_name, source_offset=psf_source_offset)
         psf_upsamp = profile['upsamp']
         psf_pixscl_x = profile['pix_sclx']
         psf_pixscl_y = profile['pix_scly']
@@ -916,8 +919,8 @@ class AdvancedPSF(object):
         scene_npix_x = model_scene.nx
         scene_npix_y = model_scene.ny
         kernel = np.asarray(profile['int'], dtype=np.float32)
-        npix_x = scene_npix_x / psf_upsamp
-        npix_y = scene_npix_y / psf_upsamp
+        npix_x = int(scene_npix_x/psf_upsamp)
+        npix_y = int(scene_npix_y/psf_upsamp)
         # Check to make sure npix is an integer
         if not (scene_npix_x % psf_upsamp) == 0:
             # This should never happen
@@ -930,13 +933,12 @@ class AdvancedPSF(object):
             message = "Number of scene pixels, {}, is not divisible by the PSF upsampling factor, {}".format(
                 scene_npix_y, psf_upsamp)
             raise DataConfigurationError(value=message)
+        
         # We have to make sure npix is an integer or it can't be used as an index
-        npix_x = int(npix_x)
-        npix_y = int(npix_y)
         new_shape = (npix_x, npix_y)
 
         # If there is a scene, convolve with it
-        if (model_scene is None) or (empty_scene):
+        if empty_scene:
             self.intensity = np.zeros((scene_npix_x,scene_npix_y))
             # self.intensity = profile['int']
         else:
@@ -946,6 +948,7 @@ class AdvancedPSF(object):
             if (np.abs(model_scene.ysamp / psf_pixscl_y - 1) > 1e-10):
                 raise ValueError("scene sampling must be the same as PSF sampling")
             windex = np.abs(model_scene.wave - wave).argmin() # find nearest index
+
             # See Issue #71 for discussion and benchmarks about
             # these different FFT methods. astropy.convolution plus pyFFTW yields a significant
             # speed-up, of order 30% or more.
@@ -960,10 +963,10 @@ class AdvancedPSF(object):
             if single:
  
                 kernel_npix_x, kernel_npix_y = kernel.shape
-                mini_x = np.int((scene_npix_x - kernel_npix_x)/2) # minimum index of the kernel size within the FOV
-                maxi_x = np.int((scene_npix_x + kernel_npix_x)/2) # maximum index of the kernel size within the FOV
-                mini_y = np.int((scene_npix_y - kernel_npix_y)/2) # minimum index of the kernel size within the FOV
-                maxi_y = np.int((scene_npix_y + kernel_npix_y)/2) # maximum index of the kernel size within the FOV
+                mini_x = int((scene_npix_x - kernel_npix_x)/2) # minimum index of the kernel size within the FOV
+                maxi_x = int((scene_npix_x + kernel_npix_x)/2) # maximum index of the kernel size within the FOV
+                mini_y = int((scene_npix_y - kernel_npix_y)/2) # minimum index of the kernel size within the FOV
+                maxi_y = int((scene_npix_y + kernel_npix_y)/2) # maximum index of the kernel size within the FOV
 
                 # if we have a rare instance where the PSF is larger than the scene, just effectively convolve it normally
                 # (without this, the tiny window would actually have no pixels in it, producing a zero cube)
@@ -992,7 +995,7 @@ class AdvancedPSF(object):
         offset rectangles. In principle, one could create an IFU with each slice consisting of discrete shutters.
         This could be used to simulate different IFU designs, such as lenslet or micro-mirror arrays.
         """
-        if aper_width is not None and aper_height is not None:
+        if aper_width is not None and aper_height is not None and slit_shape=="rectangle":
             offsets = [(i - (nslice - 1) / 2.) * aper_width for i in np.arange(nslice)]
             self.slice_int_list = []
             self.slice_int_plus_bg_list = []
@@ -1028,7 +1031,22 @@ class AdvancedPSF(object):
                 self.slice_int_plus_bg_list.append(slice_int_plus_bg)
                 self.slice_mask_list.append(slice_mask)
                 self.aperture_list.append(aperture)
-
+        elif aper_width is not None and slit_shape=="circle":
+            self.grid = Grid(psf_pixscl_x * psf_upsamp, psf_pixscl_y * psf_upsamp, npix_x, npix_y)
+            fine_grid = Grid(psf_pixscl_x, psf_pixscl_y, scene_npix_x, scene_npix_y)
+            slice_mask_fine = np.zeros(self.intensity.shape)
+            # we do not have a use case for multiple or non-centered circular slits
+            slice_mask_fine = fine_grid.circular_mask(
+                aper_width/2, 
+                xoff=0.0, 
+                yoff=0.0
+            )
+            slice_int, slice_int_plus_bg, slice_mask = self._apply_slit_mask(slice_mask_fine, new_shape)
+            aperture = {'radius': aper_width, 'offset': (0., 0)}
+            self.slice_int_list = [slice_int]
+            self.slice_int_plus_bg_list = [slice_int_plus_bg]
+            self.slice_mask_list = [slice_mask]
+            self.aperture_list = [aperture]
         else:
             # The cube indexing order is y,x
             slice_mask_fine = np.ones((scene_npix_y, scene_npix_x))
