@@ -2,6 +2,7 @@
 from __future__ import division, absolute_import
 
 import numpy as np
+import scipy.interpolate as sc
 from photutils.geometry import circular_overlap_grid, elliptical_overlap_grid
 
 from .custom_exceptions import EngineInputError
@@ -539,3 +540,35 @@ class IrregularGrid(Grid):
             self.xsamp = np.abs(xvals[1] - xvals[0])
         if len(yvals) > 1:
             self.ysamp = np.abs(yvals[1] - yvals[0])
+
+    def world_to_image(self, y, x):
+        """
+        Return fractional index coordinates yi,xi corresponding to given y,x position
+        This version can handle irregular grids (though with position found via linear
+        interpolation)
+
+        Parameters
+        ----------
+        y, x : float
+            y, x position in world coordinates
+
+        Returns
+        -------
+        pos : [yi, xi] list of floats
+            yi, xi image coordinates that correspond to given position
+        """
+        t = self.as_dict()
+        if x < t['x_min'] or x > t['x_max']:
+            raise ValueError("X outside of Grid bounds.")
+        if y < t['y_min'] or y > t['y_max']:
+            raise ValueError("Y outside of Grid bounds.")
+        x_interp = sc.interp1d(self.row, list(range(self.nx)))
+        x_image = x_interp(x)
+        #x_image = np.interp(x, self.row, list(range(self.nx)))
+        # y coordinates are flipped, requiring the lists to be flipped
+        y_interp = sc.interp1d(self.col, list(range(self.ny)))
+        y_image = y_interp(y)
+        #y_image = np.interp(y, self.col[::-1], list(range(self.ny))[::-1])
+        pos = [float(y_image), float(x_image)]
+
+        return pos
