@@ -196,6 +196,41 @@ an_sed_upload = {
     },
 }
 
+a_background_hst = {
+    'type': 'object',
+    'required': ['airglow','earthshine','zodiacallight'],
+    'additionalProperties': False,
+    'properties': {
+        'airglow': {
+            'type': 'object', 
+            'required': ['choice', 'standard'],
+            'additionalProperties': False,
+            'properties': {
+                'choice':     {'type': 'string', 'enum': ['standard']},
+                'standard':   {'type': 'string', 'enum': ['none', 'low', 'average', 'high']}
+            }
+        },
+        'earthshine': {
+            'type': 'object', 
+            'required': ['choice', 'standard'],
+            'additionalProperties': False,
+            'properties': {
+                'choice':     {'type': 'string', 'enum': ['standard']},
+                'standard':   {'type': 'string', 'enum': ['none', 'average', 'high', 'extremely_high']}
+            }
+        },
+        'zodiacallight':  {
+            'type': 'object', 
+            'required': ['choice', 'standard'],
+            'additionalProperties': False,
+            'properties': {
+                'choice':     {'type': 'string', 'enum': ['standard']},
+                'standard':   {'type': 'string', 'enum': ['none', 'low', 'average', 'high']}
+            }
+        }
+    }
+}
+
 a_background_none = {
     'type': 'object',
     'required': ['bg_type'],
@@ -233,7 +268,7 @@ a_background_dated = {
 
 a_background_choice = {
     'type': 'object',
-    'oneOf': [a_background_none, a_background_dateless, a_background_dated],
+    'oneOf': [a_background_hst, a_background_none, a_background_dateless, a_background_dated],
 }
 
 a_dither_simple = {
@@ -555,29 +590,57 @@ a_source = {
     },
 }
 
+a_detector_hst = {
+    'type': 'object',
+    'required': ['calculate_snr','snr','time'],
+    'additionalProperties': False,
+    'properties': {
+        'bin_dispersion':  {'type': 'number'}, # optional
+        'bin_spatial':     {'type': 'number'}, # optional
+        'calculate_snr':   {'type': 'boolean'},
+        'dark_level':      {'type': 'string'}, # optional
+        'gain':            {'type': 'number'}, # optional
+        'fuv_glow_region': {'type': 'string'}, # optional
+        'nexp':            {'type': 'number'}, # optional
+        'nsplit':          {'type': 'number'}, # optional
+        'snr':             {'type': 'number'},
+        'time':            {'type': 'number'},
+    },
+}
+
+a_detector_jwst = {
+    'type': 'object',
+    'required': ['nexp','ngroup','nint','readout_pattern'],
+    'additionalProperties': False,
+    'properties': {
+        'nexp':            {'type': 'number'},
+        'ngroup':          {'type': 'number'},
+        'nint':            {'type': 'number'},
+        'readout_pattern': {'type': 'string'},
+        'subarray':        {'type': 'string'}, # optional
+    },
+}
+
+a_detector_for_st = {
+    'type': 'object',
+    'oneOf': [a_detector_hst, a_detector_jwst],
+}
+
 a_camera_config = {
     'type': 'object',
     'required': ['detector','instrument'],
     'additionalProperties': False,
     'properties': {
-        'detector': {
-            'type': 'object',
-            'required': ['nexp','ngroup','nint','readout_pattern'],
-            'additionalProperties': False,
-            'properties': {
-                'nexp':            {'type': 'number'},
-                'ngroup':          {'type': 'number'},
-                'nint':            {'type': 'number'},
-                'readout_pattern': {'type': 'string'},
-                'subarray':        {'type': 'string'}, # optional
-            },
-        },
+        'detector': a_detector_for_st,
         'instrument': {
             'type': 'object',
             'required': ['aperture','disperser','filter'],
             'additionalProperties': False,
             'properties': {
                 'aperture':         {'type': 'string'},
+                'cenwave':          {'type': 'string'}, # optional, HST only, may break all this up
+                'slit':             {'type': 'string'}, # optional, HST only, may break all this up
+                'detector':         {'type': 'string'}, # optional
                 'disperser':        {'oneOf': [{'type': 'string'}, {'type': 'null'}]},
                 'filter':           {'oneOf': [{'type': 'string'}, {'type': 'null'}]},
                 'shutter_location': {'type': 'string'}, # optional
@@ -668,6 +731,7 @@ WORKBOOK_SCHEMA = {
         'an_sed_blackbody':             an_sed_blackbody,
         'an_sed_powerlaw':              an_sed_powerlaw,
         'an_sed_keyed':                 an_sed_keyed,
+        'a_background_hst':             a_background_hst,
         'a_background_none':            a_background_none,
         'a_background_dateless':        a_background_dateless,
         'a_background_dated':           a_background_dated,
@@ -692,6 +756,12 @@ WORKBOOK_SCHEMA = {
         'a_scene':                      a_scene,
         'a_source':                     a_source,
 
+        # config
+        'a_detector_for_st':            a_detector_for_st,
+        'a_detector_hst':               a_detector_hst,
+        'a_detector_jwst':              a_detector_jwst,
+        'a_camera_config':              a_camera_config,
+
         # calculations
         'a_calculation':                a_calculation,
     },
