@@ -44,6 +44,12 @@ class JWSTInstrument(Instrument):
 
         Instrument.__init__(self, telescope=telescope, mode=mode, config=config, webapp=webapp, **kwargs)
 
+    def read_detector(self):
+        """Read in the detector keyword from the aperture parameter in the config json file.
+           Put the detector keyword in self.instrument['detector']."""
+        if "slit" in self.aperture_config[self.get_aperture()]:
+            self.instrument['slit'] = self.aperture_config[self.get_aperture()]['slit']
+        self.instrument['detector'] = self.aperture_config[self.get_aperture()]['detector']
 
 class NIRSpec(JWSTInstrument):
 
@@ -61,19 +67,25 @@ class NIRSpec(JWSTInstrument):
 
         JWSTInstrument.__init__(self, mode=mode, config=config, webapp=webapp, **kwargs)
 
-        aperture = self.instrument['aperture']
-        if self.mode == "msa":
-            shutter_location = self.instrument['shutter_location']
-            gap_config_file = self.aperture_config[aperture].pop('gap')
-            gap_config = read_json(os.path.join(self.ref_dir, gap_config_file), raise_except=True)
-            self.shutter_locations = list(gap_config.keys())
+        slit = self.instrument.get('slit',None)
+        if slit is not None:
             try:
-                self.gap = gap_config[shutter_location]
+                slit_config = self.slit_config[slit]
             except KeyError as e:
-                msg = "Shutter location not specified for MSA calculation: %s" % e
+                msg = "Configuration for slit {} not specified".format(slit)
                 raise DataError(value=msg)
-        else:
-            self.gap = self.read_config_param(self.aperture_config[aperture], "gap")
+            if self.mode == "msa":
+                shutter_location = self.instrument['shutter_location']
+                gap_config_file = slit_config.pop('gap')
+                gap_config = read_json(os.path.join(self.ref_dir, gap_config_file), raise_except=True)
+                self.shutter_locations = list(gap_config.keys())
+                try:
+                    self.gap = gap_config[shutter_location]
+                except KeyError as e:
+                    msg = "Shutter location not specified for MSA calculation: %s" % e
+                    raise DataError(value=msg)
+            else:
+                self.gap = self.read_config_param(slit_config, "gap")
 
     def get_wave_range(self):
         """
@@ -147,19 +159,22 @@ class NIRSpec(JWSTInstrument):
         aperture = self.instrument['aperture']
         filt = self.instrument['filter']
         # MSA shutter configuration is read in from a separate file in a different way
-        gap = self.gap[disperser]
+        if hasattr(self, "gap"):
+            gap = self.gap[disperser]
 
-        if filt in gap:
-            gap_start = gap[filt]['gap_start']
-            gap_end = gap[filt]['gap_end']
-        else:
-            gap_start = gap['gap_start']
-            gap_end = gap['gap_end']
+            if filt in gap:
+                gap_start = gap[filt]['gap_start']
+                gap_end = gap[filt]['gap_end']
+            else:
+                gap_start = gap['gap_start']
+                gap_end = gap['gap_end']
 
-        if gap_start is not None and gap_end is not None:
-            masked_wave = ma.masked_inside(wave, gap_start, gap_end)
-            mask = masked_wave / wave
-            mask = ma.filled(mask, 0.0)
+            if gap_start is not None and gap_end is not None:
+                masked_wave = ma.masked_inside(wave, gap_start, gap_end)
+                mask = masked_wave / wave
+                mask = ma.filled(mask, 0.0)
+            else:
+                mask = 1.0
         else:
             mask = 1.0
         return mask
@@ -232,18 +247,6 @@ class NIRCam(JWSTInstrument):
             eff = self._get_throughput(wave, self.instrument['filter'])
         return eff
 
-    def get_detector_pars(self):
-        aperture = self.instrument['aperture']
-        if aperture in self.apertures_lw:
-            self.detector_key = 'lw'
-        elif aperture in self.apertures_sw:
-            self.detector_key = 'sw'
-        else:
-            msg = "Unknown NIRCam aperture %s" % aperture
-            raise EngineInputError(value=msg)
-
-        return self.read_detector_pars()
-
     def get_internal_eff(self, wave):
         """
         Read in internal efficiency. For NIRCam there are separate internal efficiencies for the optics common
@@ -266,20 +269,8 @@ class NIRCam(JWSTInstrument):
         dichroic_eff = 1.0
         pupil_eff = 1.0
 
-        # load the dichroic throughput based on which channel we're using
-        ap = self.aperture_config[self.instrument['aperture']]
-        if 'channel' not in ap:
-            msg = "Channels not configured for NIRCam aperture %s." % self.instrument['aperture']
-            raise DataError(value=msg)
-
-        # load the dichroic effects for the correct channel
-        if ap['channel'] == 'sw':
-            dichroic_eff = self._get_throughput(wave, 'dbs_sw')
-        elif ap['channel'] == 'lw':
-            dichroic_eff = self._get_throughput(wave, 'dbs_lw')
-        else:
-            msg = "Channel %s not configured for NIRCam aperture %s." % (ap['channel'], self.instrument['aperture'])
-            raise DataError(value=msg)
+        # load the dichroic effects for the correct detector. Note that _get_throughput defaults to returning 1
+        dichroic_eff = self._get_throughput(wave, 'dbs_{}'.format(self.instrument['detector']))
 
         # load the weak lens pupil transmission, if applicable
         if "wlp8" in self.instrument['aperture']:
@@ -287,10 +278,7 @@ class NIRCam(JWSTInstrument):
 
         if self.instrument['mode'] == 'coronagraphy':
             coronagraphy_eff = self._get_throughput(wave, 'coronagraphy_substrate')
-            if self.instrument['aperture'] in ('maskswb', 'mask210r'):
-                wedge_eff = self._get_throughput(wave, 'sw_wedge_eff')
-            if self.instrument['aperture'] == ('masklwb', 'mask335r', 'mask430r'):
-                wedge_eff = self._get_throughput(wave, 'lw_wedge_eff')
+            wedge_eff = self._get_throughput(wave, '{}_wedge_eff'.format(self.instrument['detector']))
         eff = base_eff * coronagraphy_eff * wedge_eff * dichroic_eff * pupil_eff
 
         return eff
@@ -356,19 +344,12 @@ class NIRCam(JWSTInstrument):
         Need to over-ride get_detector_qe() to handle the two different detectors. Which one to use is keyed off
         of the configured aperture.
         """
-        aperture = self.instrument['aperture']
         try:
-            channel = self.aperture_config[aperture]['channel']
+            detector = self.instrument['detector']
         except KeyError as e:
-            msg = "NIRCam aperture configuration must include which channel the aperture belongs to, sw or lw. (%s)" % e
-            raise DataError(value=msg)
-        if channel == 'lw':
-            qe = self._get_throughput(wave, 'qe_lw')
-        elif channel == 'sw':
-            qe = self._get_throughput(wave, 'qe_sw')
-        else:
-            msg = "Unknown NIRCam channel %s" % channel
+            msg = "NIRCam aperture configuration must include which detector the aperture belongs to, sw or lw. (%s)" % e
             raise DataError(value=msg)
+        qe = self._get_throughput(wave, 'qe_{}'.format(detector))
 
         return qe
 
@@ -559,27 +540,10 @@ class MIRI(JWSTInstrument):
         key: string
             Key for looking up the appropriate QE reference file
         """
-        aperture = self.instrument["aperture"]
-        if aperture in ['ch1', 'ch2']:
-            key = "miri_sw_qe"
-        elif aperture in ['ch3', 'ch4']:
-            key = "miri_lw_qe"
-        else:
-            key = "miri_imager_qe"
+        key = "miri_{}_qe".format(self.instrument['detector'])
+
         return key
 
-    def get_detector_pars(self):
-        disperser = self.instrument["disperser"]
-        aperture = self.instrument["aperture"]
-
-        if aperture == 'ch1' or aperture == 'ch2':
-            self.detector_key = "sw"
-        elif aperture == 'ch3' or aperture == 'ch4':
-            self.detector_key = "lw"
-        elif disperser is None or disperser == 'p750l':
-            self.detector_key = "imager"
-        return self.read_detector_pars()
-
     def get_variance_fudge(self, wave):
         """
         In addition to a scalar fudge factor, MIRI also has a chromatic variance fudge that correlates with
@@ -588,8 +552,7 @@ class MIRI(JWSTInstrument):
         to provide the chromatic fudge factor they want as a separate reference file. Until that's delivered, we'll
         use the quantum yield squared to achieve the desired effect.
         """
-        det_pars = self.get_detector_pars()
-        scalar_fudge = det_pars.get('var_fudge', 1.0)
+        scalar_fudge = self.the_detector._get_variance_fudge(wave)
         q_yield, fano_factor = self.get_quantum_yield(wave)
         var_fudge = scalar_fudge * q_yield**2
 
