@@ -18,7 +18,6 @@ from pandeia.engine.calc_utils import build_default_calc, build_default_source
 
 from ipywidgets import widgets, GridspecLayout
 from IPython.display import display, clear_output
-import traitlets
 
 refdata = os.environ['pandeia_refdata']
 
@@ -42,12 +41,13 @@ def get_config(filename):
         JSON configuration data with keys swapped out for display_strings where available.
     """
     conf_data = read_json(filename)
-    conf = {}
+    conf = []
     for k in conf_data:
         if "display_string" in conf_data[k]:
-            conf[conf_data[k]["display_string"]] = k
+            entry = (conf_data[k]["display_string"], k)
         else:
-            conf[k] = k
+            entry = (k.upper(), k)
+        conf.append(entry)
     return conf
 
 dummy = None
@@ -524,15 +524,16 @@ class Roman_gui(object):
     def __init__(self):
         self.r = {}
         usernotes = widgets.HTML(value="<b>If no advanced settings are changed,</b> a centered point source with no "
-                                      "redshift will be computed using readout pattern 'medium8' and subarray '1024x1024', "
+                                       "redshift will be computed using readout pattern 'medium8' and subarray 'imaging', "
                                        "with extraction aperture centered at 0,0 with a size of 0.1 arcsec, and a sky "
-                                      "annulus from 0.2-0.3 arcsec."
+                                       "annulus from 0.2-0.3 arcsec."
                                        "<p>The readout patterns are currently inherited from JWST NIRCam. To best "
                                        "approximate readouts as currently envisioned for Roman, we suggest using the "
-                                       "following:</p>"
-                                       "<ul>"
-                                       "<li>Subarray '1024x1024', which has a similar frame time (2.7s) as that "
-                                       "expected for the Roman WFI. </li>"
+                                       "following: </p> <p>- For imaging modes:</p>" 
+                                       "<li>Subarray: 'imaging' which has a frame time of 3.04s</li>"
+                                       "<p>- For spectroscopic modes:</p>"
+                                       "<li>subarray: 'spectroscopic' which has a frame time of 4.03s</li>"
+                                       "<p>The larger subarrays of “defocus_large” and “defocus_small” are for internal testing only.</p>"
                                        #"<li>Roman does not currently anticipate resetting the detector during an "
                                        #"exposure.  Thus Integrations should be set to 1.</li>"
                                        "<li><i>To approximate the current design for the High Latitude Imaging "
@@ -542,7 +543,6 @@ class Roman_gui(object):
                                        "<li><i>To approximate the current design for the Exoplanet Microlensing "
                                        "Survey:</i> readout pattern 'shallow2' with Ngroups = 4</li")
 
-
         self.form = widgets.VBox(width="100%", background_color="#EEE")
         sourcetitle = widgets.HTML(value="<h3>SOURCES</h3>")
 
@@ -849,15 +849,15 @@ class Roman_gui(object):
                     del s['spectrum']['sed']['unit']
                 elif sed == "phoenix":
                     s['spectrum']['sed']['sed_type'] = "phoenix"
-                    s['spectrum']['sed']['key'] = source.phoenix_config[source.phoenix.value]
+                    s['spectrum']['sed']['key'] = source.phoenix.value
                     del s['spectrum']['sed']['unit']
                 elif sed == "extragalactic":
                     s['spectrum']['sed']['sed_type'] = "brown"
-                    s['spectrum']['sed']['key'] = source.gal_config[source.galaxies.value]
+                    s['spectrum']['sed']['key'] = source.galaxies.value
                     del s['spectrum']['sed']['unit']
                 elif sed == "star":
                     s['spectrum']['sed']['sed_type'] = "hst_calspec"
-                    s['spectrum']['sed']['key'] = source.star_config[source.star.value]
+                    s['spectrum']['sed']['key'] = source.star.value
                     del s['spectrum']['sed']['unit']
 
                 c['scene'].append(s)
