@@ -26,8 +26,6 @@ from . import io_utils as io
 from . import config as cf
 
 default_refdata_directory = cf.default_refdata_directory
-# Change the Vega file to point to ours
-syn.config.conf.vega_file = '{}/normalization/alpha_lyr_stis_008.fits'.format(default_refdata_directory)
 
 class Normalization(DefaultConfig):
 
@@ -261,7 +259,7 @@ class NormalizePhotsys(Normalization):
         try:
             keys = get_key_list(self.bandpass, separator=',')  # should be [photsys, filter]
             bp_filename = get_dict_from_keys(self.bandpasses, keys)['filename']
-            bp_path = os.path.join(default_refdata_directory, "normalization", "bandpass", bp_filename)
+            bp_path = os.path.join(os.environ.get("PYSYN_CDBS"), "comp", "nonhst", bp_filename)
             bp = syn.spectrum.SpectralElement.from_file(bp_path)
         except Exception as e:
             msg = "Error loading normalization bandpass: %s " % self.bandpass
