@@ -22,7 +22,7 @@ class PSFLibrary:
         the path to the PSF library root (any .fits files in the
         path root will be assumed to be a valid PSF file in the WebbPSF format.
         If it is none, the PSF library from the package distribution will be used.
-    aperture : string, optional
+    psf_key : string, optional
         restrict psfs to a specific mode with the name matching the keyword string.
         Strictly, the reader will look for psf file names with a substring matching the aperture
         string. 'all' reads all psfs in the path. This is the default. The aperture string in the filename
@@ -37,10 +37,10 @@ class PSFLibrary:
 
     """
 
-    def __init__(self, path=None, aperture='all'):
+    def __init__(self, path=None, psf_key='all'):
         if path is None:
             path = os.path.join(os.path.dirname(__file__), 'refdata', 'psfs')
-        self.read_library(path, aperture)
+        self.read_library(path, psf_key)
 
     def read_library(self, path, aperture, wave_unit='m'):
         """
@@ -71,7 +71,7 @@ class PSFLibrary:
             filename_wave = filename_split[2]
             # If the psf is on-axis, the offset coordinates may not exist
 
-            if aperture is 'all':
+            if aperture == 'all':
                 if ext == '.fits':
                     psf_files.append(file)
             elif ext == '.fits' and aperture in filename_apertures:
