@@ -9,7 +9,7 @@ from astropy import units as u
 import synphot as syn
 from synphot.models import Empirical1D, ConstFlux1D
 import stsynphot as stsyn
-import astropy
+from astropy.units import Quantity
 from astropy.modeling.models import BlackBody as Black_Body
 
 from .config import DefaultConfig
@@ -49,6 +49,7 @@ class SED(DefaultConfig):
         if not hasattr(self, "sed_type"):
             self.sed_type = self.__class__.__name__.lower()
 
+        sed_config = {}
         if self.sed_type in self.sed_types:
             sed_config = self.sed_types[self.sed_type]
             if "defaults" in sed_config:
@@ -191,7 +192,10 @@ class Analytic(SED):
         try:
             k = -self.sampling * np.log(self.wmin)
             nw = int(self.sampling * np.log(self.wmax) + k)
-            wave = np.exp((np.arange(nw) - k) / self.sampling)
+            # nw + 1 almost spans the wavelength range, while nw + 2 guarantees 
+            # the highest wavelength will be above the requested range and
+            # therefore never require any extrapolation.
+            wave = np.exp((np.arange(nw + 2) - k) / self.sampling)
         except ValueError as e:
             msg = "Error creating wavelength grid for wmin=%f, wmax=%s with sampling=%d: %s" % (
                 self.wmin,
@@ -406,7 +410,7 @@ class Phoenix(Parameterized):
 
     def get_spectrum(self):
         """
-        Use synphot.grid_to_spec() to calculate spectrum and convert to microns/mJy.  If self.webapp=True,
+        Use stsynphot.grid_to_spec() to calculate spectrum and convert to microns/mJy.  If self.webapp=True,
         use key to look up a specified set of parameters.  Otherwise, get them from the configured
         attributes.
         """
@@ -434,6 +438,61 @@ class Phoenix(Parameterized):
         return sp.waveset, sp(sp.waveset, flux_unit=PANDEIA_FLUXUNITS)
 
 
+class K93Models(Parameterized):
+
+    """
+    Class implementing the Kurucz (1993) parameterized stellar spectrum models. The inputs to the models
+    are:
+
+    teff - effective temperature (K; range 3500 to 50000)
+    log_g - surface gravity (log10 in cgs units; range 0.0 to 5.0)
+
+    If used with webapp=True, the parameters will come from a configured look-up table
+    using a provided key. Otherwise the model parameters will be taken from default configuration or input.
+    """
+
+    def __init__(self, webapp=False, config={}, **kwargs):
+        if webapp:
+            self.api_parameters = ["sed_type", "key"]
+            self.api_ignore = ["spectrum_id", "teff", "log_g", "comment", "display_string", "spectra", "z"]
+        else:
+            self.api_parameters = ["sed_type", "teff", "log_g"]
+            self.api_ignore = ["spectrum_id", "key", "comment", "display_string", "spectra", "z"]
+
+        Parameterized.__init__(self, webapp=webapp, config=config, **kwargs)
+
+    def get_spectrum(self):
+        """
+        Use stsynphot.grid_to_spec() to calculate spectrum and convert to microns/mJy.  If self.webapp=True,
+        use key to look up a specified set of parameters.  Otherwise, get them from the configured
+        attributes.
+        """
+        if self.webapp:
+            if self.key not in self.spectra:
+                msg = "Provided SED key, %s, not supported." % self.key
+                raise EngineInputError(value=msg)
+            pars = self.spectra[self.key]
+            t = pars['teff']
+            m = 0
+            g = pars['log_g']
+        else:
+            t = self.teff
+            m = 0
+            g = self.log_g
+        try:
+            sp = stsyn.grid_to_spec('k93models', t, m, g)
+        except Exception as e:
+            msg = "Error creating K93 model spectrum via Synphot. "
+            if self.webapp:
+                msg += "(%s)" % type(e)
+            else:
+                msg += repr(e)
+            raise SynphotError(value=msg)
+        # The k93 output is float32, at least the wavelength needs to be float64 for extinction
+        return Quantity(sp.waveset, dtype=np.float64), sp(sp.waveset, flux_unit=PANDEIA_FLUXUNITS)
+
+
+
 class Mapped(SED):
 
     """
@@ -519,6 +578,33 @@ class CDBS(Mapped):
             raise DataError("File for SED key {} not found.".format(self.key))
         return sp.waveset, sp(sp.waveset, flux_unit=PANDEIA_FLUXUNITS)
 
+class Custom(CDBS):
+
+    """
+    Class implementing custom user-specified CDBS spectra
+    """
+
+    def __init__(self, webapp=False, config={}, **kwargs):
+        """
+        How an SED is configured depends on the defaults and any input configuration.
+
+        Parameters
+        ----------
+        webapp: bool
+            Determines whether strict API checks should be performed
+        config: dict
+            Extra configuration information in engine input API dict format
+        **kwargs: keyword/value pairs
+            Extra configuration information in kwargs format
+        """
+        self.api_parameters = ["sed_type", "key"]
+        SED.__init__(self, webapp=webapp, config=config, **kwargs)
+        self.spectra = {self.key: {"filename": self.key}} # the key IS the filename
+        self.wave, self.flux = self.get_spectrum()
+        self.wave = Quantity(self.wave, dtype=np.float64)
+        self.wmin = self.wave.min()
+        self.wmax = self.wave.max()
+
 class Brown2014(CDBS):
 
     """
